@@ -103,7 +103,7 @@ ap_bs_Mouse MouseTable[] =
 	{_CZ _B0,	{ "",	"",			"btn0InlineImage",	"",			"",			""				}},
 	{_CF _B0,	{ "",	"",			"cursorDefault",	"",			"",			""				}},
 	{_CR _B0,	{ "",	"",			"cursorDefault",	"",			"",			""				}},
-	{_CH _B0,	{ "",	"",			"hyperlinkStatusBar",	"",			"",			"",				}},
+	{_CH _B0,	{ "hyperlinkStatusBar",	"hyperlinkStatusBar",			"hyperlinkStatusBar",	"",			"",			"",				}},
 	{_CTV _B0,	{ "",	"",			"cursorVline",	"",			"",			"",				}},
 	{_CTH _B0,	{ "",	"",			"cursorHline",	"",			"",			"",				}},
 	{_CTF _B0,	{ "",	"",			"btn0Frame",	"",			"",			"",				}},
@@ -497,7 +497,7 @@ ap_bs_Char CharTable[] =
 	{0x3a, /* :      */ { "insertData",			"",					"",				""					}},
 	{0x3b, /* ;      */ { "insertData",			"",					"",				""					}},
 	{0x3c, /* <      */ { "insertData",			"fontSizeDecrease",	"",				"insertRLM"			}},
-	{0x3d, /* =      */ { "insertData",			"toggleSuper",		"toggleSub",	""					}},
+	{0x3d, /* =      */ { "insertData",			"zoomIn",   		"zoomIn",	""					}},
 	{0x3e, /* >      */ { "insertData",			"fontSizeIncrease",	"",				"insertLRM"			}},
 	{0x3f, /* ?      */ { "insertData",			"",					"",				""					}},
 	{0x40, /* @      */ { "insertData",			"",					"",				""					}},
@@ -530,9 +530,9 @@ ap_bs_Char CharTable[] =
 	{0x5b, /* [      */ { "insertOpeningParenthesis","editHeader",	"",				""					}},
 	{0x5c, /* \      */ { "insertData",			"removeHeader",		"",				""					}},
 	{0x5d, /* ]      */ { "insertClosingParenthesis","editFooter",	"",				""					}},
-	{0x5e, /* ^      */ { "insertData",			"removeFooter",		"",				""					}},
-	{0x5f, /* -      */ { "insertData",			"",					"",				""					}},
-	{0x60, /* `      */ { "insertData",			"",					"",				""					}},
+	{0x5e, /* ^      */ { "insertData",			"toggleSuper",		"",				""					}},
+	{0x5f, /* _      */ { "insertData",			"toggleSub",		"",				""					}},
+	{0x60, /* `      */ { "insertData",			"removeFooter",		"",				""					}},
 	{0x61, /* a      */ { "insertData",			"selectAll",		DO_NOT_USE,		""					}},
 	{0x62, /* b      */ { "insertData",			"toggleBold",		DO_NOT_USE,		""					}},
 	{0x63, /* c      */ { "insertData",			"copy",				DO_NOT_USE,		""					}},
